@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import (
     CpuVendorArchitectureType,
@@ -168,8 +168,8 @@ AutoScalingGroupRecommendationTypeDef = TypedDict(
 DescribeRecommendationExportJobsRequestRequestTypeDef = TypedDict(
     "DescribeRecommendationExportJobsRequestRequestTypeDef",
     {
-        "jobIds": List[str],
-        "filters": List["JobFilterTypeDef"],
+        "jobIds": Sequence[str],
+        "filters": Sequence["JobFilterTypeDef"],
         "nextToken": str,
         "maxResults": int,
     },
@@ -189,7 +189,7 @@ EBSFilterTypeDef = TypedDict(
     "EBSFilterTypeDef",
     {
         "name": Literal["Finding"],
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -208,7 +208,7 @@ EnrollmentFilterTypeDef = TypedDict(
     "EnrollmentFilterTypeDef",
     {
         "name": Literal["Status"],
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -222,9 +222,9 @@ _RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
 _OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
     "_OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
-        "accountIds": List[str],
-        "filters": List["FilterTypeDef"],
-        "fieldsToExport": List[ExportableAutoScalingGroupFieldType],
+        "accountIds": Sequence[str],
+        "filters": Sequence["FilterTypeDef"],
+        "fieldsToExport": Sequence[ExportableAutoScalingGroupFieldType],
         "fileFormat": Literal["Csv"],
         "includeMemberAccounts": bool,
         "recommendationPreferences": "RecommendationPreferencesTypeDef",
@@ -266,9 +266,9 @@ _RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
 _OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
     "_OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef",
     {
-        "accountIds": List[str],
-        "filters": List["EBSFilterTypeDef"],
-        "fieldsToExport": List[ExportableVolumeFieldType],
+        "accountIds": Sequence[str],
+        "filters": Sequence["EBSFilterTypeDef"],
+        "fieldsToExport": Sequence[ExportableVolumeFieldType],
         "fileFormat": Literal["Csv"],
         "includeMemberAccounts": bool,
     },
@@ -301,9 +301,9 @@ _RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
 _OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
     "_OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef",
     {
-        "accountIds": List[str],
-        "filters": List["FilterTypeDef"],
-        "fieldsToExport": List[ExportableInstanceFieldType],
+        "accountIds": Sequence[str],
+        "filters": Sequence["FilterTypeDef"],
+        "fieldsToExport": Sequence[ExportableInstanceFieldType],
         "fileFormat": Literal["Csv"],
         "includeMemberAccounts": bool,
         "recommendationPreferences": "RecommendationPreferencesTypeDef",
@@ -337,9 +337,9 @@ _RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
 _OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
     "_OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
-        "accountIds": List[str],
-        "filters": List["LambdaFunctionRecommendationFilterTypeDef"],
-        "fieldsToExport": List[ExportableLambdaFunctionFieldType],
+        "accountIds": Sequence[str],
+        "filters": Sequence["LambdaFunctionRecommendationFilterTypeDef"],
+        "fieldsToExport": Sequence[ExportableLambdaFunctionFieldType],
         "fileFormat": Literal["Csv"],
         "includeMemberAccounts": bool,
     },
@@ -367,7 +367,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "name": FilterNameType,
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -375,11 +375,11 @@ FilterTypeDef = TypedDict(
 GetAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
     "GetAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
-        "accountIds": List[str],
-        "autoScalingGroupArns": List[str],
+        "accountIds": Sequence[str],
+        "autoScalingGroupArns": Sequence[str],
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "recommendationPreferences": "RecommendationPreferencesTypeDef",
     },
     total=False,
@@ -398,11 +398,11 @@ GetAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
 GetEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
     "GetEBSVolumeRecommendationsRequestRequestTypeDef",
     {
-        "volumeArns": List[str],
+        "volumeArns": Sequence[str],
         "nextToken": str,
         "maxResults": int,
-        "filters": List["EBSFilterTypeDef"],
-        "accountIds": List[str],
+        "filters": Sequence["EBSFilterTypeDef"],
+        "accountIds": Sequence[str],
     },
     total=False,
 )
@@ -420,11 +420,11 @@ GetEBSVolumeRecommendationsResponseTypeDef = TypedDict(
 GetEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
     "GetEC2InstanceRecommendationsRequestRequestTypeDef",
     {
-        "instanceArns": List[str],
+        "instanceArns": Sequence[str],
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
-        "accountIds": List[str],
+        "filters": Sequence["FilterTypeDef"],
+        "accountIds": Sequence[str],
         "recommendationPreferences": "RecommendationPreferencesTypeDef",
     },
     total=False,
@@ -489,7 +489,7 @@ GetEnrollmentStatusResponseTypeDef = TypedDict(
 GetEnrollmentStatusesForOrganizationRequestRequestTypeDef = TypedDict(
     "GetEnrollmentStatusesForOrganizationRequestRequestTypeDef",
     {
-        "filters": List["EnrollmentFilterTypeDef"],
+        "filters": Sequence["EnrollmentFilterTypeDef"],
         "nextToken": str,
         "maxResults": int,
     },
@@ -508,9 +508,9 @@ GetEnrollmentStatusesForOrganizationResponseTypeDef = TypedDict(
 GetLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
     "GetLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
-        "functionArns": List[str],
-        "accountIds": List[str],
-        "filters": List["LambdaFunctionRecommendationFilterTypeDef"],
+        "functionArns": Sequence[str],
+        "accountIds": Sequence[str],
+        "filters": Sequence["LambdaFunctionRecommendationFilterTypeDef"],
         "nextToken": str,
         "maxResults": int,
     },
@@ -539,7 +539,7 @@ GetRecommendationErrorTypeDef = TypedDict(
 GetRecommendationSummariesRequestRequestTypeDef = TypedDict(
     "GetRecommendationSummariesRequestRequestTypeDef",
     {
-        "accountIds": List[str],
+        "accountIds": Sequence[str],
         "nextToken": str,
         "maxResults": int,
     },
@@ -589,7 +589,7 @@ JobFilterTypeDef = TypedDict(
     "JobFilterTypeDef",
     {
         "name": JobFilterNameType,
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -618,7 +618,7 @@ LambdaFunctionRecommendationFilterTypeDef = TypedDict(
     "LambdaFunctionRecommendationFilterTypeDef",
     {
         "name": LambdaFunctionRecommendationFilterNameType,
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -687,7 +687,7 @@ RecommendationExportJobTypeDef = TypedDict(
 RecommendationPreferencesTypeDef = TypedDict(
     "RecommendationPreferencesTypeDef",
     {
-        "cpuVendorArchitectures": List[CpuVendorArchitectureType],
+        "cpuVendorArchitectures": Sequence[CpuVendorArchitectureType],
     },
     total=False,
 )
